<?php

/**
 * @category  Shopware
 * @package   Shopware\Plugins\n2goExtendApi
 */
class Shopware_Plugins_Core_N2goExtendApi_Bootstrap extends Shopware_Components_Plugin_Bootstrap
{
    /**
     * Capabilities for plugin.
     * 
     * @return array
     */
    public function getCapabilities()
    {
        return array(
            'install' => true,
            'update' => true,
            'enable' => true
        );
    }
    
    /**
     * Label for plugin.
     * 
     * @return string
     */
    public function getLabel()
    {
        return 'Newsletter2Go E-Mail Marketing';
    }
    
    /**
     * Version for plugin.
     * 
     * @return string
     */
    public function getVersion()
    {
        return '1.1.1';
    }
    
    /**
     * Informations about plugin.
     * 
     * @return array
     */
    public function getInfo()
    {
        return array(
            'version' => $this->getVersion(),
            'label' => $this->getLabel(),
            'author' => 'Newsletter2Go',
            'copyright' => 'Copyright © ' . date('Y') . ', Newsletter2Go GmbH',
            'supplier' => 'Newsletter2Go GmbH',
            'description' => 'Plugin for extending Shopware REST API.',
            'support' => 'https://www.newsletter2go.de/hilfe/',
            'link' => 'http://www.newsletter2go.de'
        );
    }
    
    /**
     * @return bool
     */
    public function install()
    {
        $this->subscribeEvents();
 
        return true;
    }
 
    /**
     * Registers all necessary events and hooks.
     */
    private function subscribeEvents()
    {
        $this->subscribeEvent(
            'Enlight_Controller_Front_StartDispatch',
            'onEnlightControllerFrontStartDispatch'
        );
 
        $this->subscribeEvent(
            'Enlight_Controller_Dispatcher_ControllerPath_Api_NewsletterCustomers',
            'onGetNewsletterCustomersApiController'
        );
        
        $this->subscribeEvent(
            'Enlight_Controller_Dispatcher_ControllerPath_Api_NewsletterArticles',
            'onGetNewsletterArticlesApiController'
        );
    }
 
    /**
     * @param Enlight_Event_EventArgs $args
     */
    public function onEnlightControllerFrontStartDispatch(Enlight_Event_EventArgs $args)
    {
        $this->Application()->Loader()->registerNamespace(
            'Shopware\Components',
            $this->Path() . 'Components/'
        );
    }
 
    /**
     * @return string
     */
    public function onGetNewsletterCustomersApiController()
    {
        return $this->Path() . 'Controllers/Api/NewsletterCustomers.php';
    }
    
    /**
     * @return string
     */
    public function onGetNewsletterArticlesApiController()
    {
        return $this->Path() . 'Controllers/Api/NewsletterArticles.php';
    }
}
