<?php
namespace Shopware\Components\Api\Resource;

use Shopware\Components\Api\Exception as ApiException;

/**
 * @category  Shopware
 * @package   Shopware\Plugins\n2goExtendApi
 */
class NewsletterCustomer extends Resource
{
    /**
     * @return \Shopware\Models\Customer\Repository
     */
    public function getRepositoryCustomer()
    {
        return $this->getManager()->getRepository('Shopware\Models\Customer\Customer');
    }
    
    /**
     * @return \Shopware\Models\Newsletter\Repository
     */
    public function getRepositoryAddress()
    {
        return $this->getManager()->getRepository('Shopware\Models\Newsletter\Address');
    }

    /**
     * @param array $criteria
     * @param array $orderBy
     * @param array $subscribed
     * @param int $offset
     * @param int $limit
     * @return array
     */
    public function getList(array $criteria = array(), array $orderBy = array(), $subscribed = false, 
            $countOnly = false, $offset = false, $limit = false)
    {
        $this->checkPrivilege('read');

        $builder = $this->getRepositoryCustomer()
            ->createQueryBuilder('customer')
            ->leftJoin('customer.billing', 'billing')
            ->where('customer.active = true');

        if ($subscribed) {
            $builder->andWhere('customer.email IN (SELECT address.email FROM Shopware\Models\Newsletter\Address address)');
        }
        
        $builder->addFilter($criteria);
        $builder->addOrderBy($orderBy);
        if ($countOnly) {
            // number of subscribers who are not customers
            $q = 'SELECT count(distinct email) FROM s_campaigns_mailaddresses WHERE email NOT IN (SELECT email from s_user)';
            $countSubscribers = Shopware()->Db()->fetchOne($q);

            $builder->select('count(customer.id)');
            $query = $builder->getQuery();
            $count = $query->getSingleScalarResult() + $countSubscribers;

            return array('data' => array(), 'total' => $count);
        }

        $builder->select('customer', 'billing');

        if ($offset !== false && $limit) {
            $builder->setFirstResult($offset)
                    ->setMaxResults($limit);
        }

        $query = $builder->getQuery();
        $query->setHydrationMode($this->getResultMode());
        $paginator = $this->getManager()->createPaginator($query);

        $customers = $paginator->getIterator()->getArrayCopy();
        $countCustomers = $paginator->count();
        
        $countries = Shopware()->Db()->fetchAll('SELECT * FROM s_core_countries');
        $country = array();
        foreach ($countries as $c) {
            $country[$c['id']] = $c['countryname'];
        }
        
        $emails = Shopware()->Db()->fetchAll('SELECT email FROM s_campaigns_mailaddresses');
        $subscribers = array();
        foreach ($emails as $e) {
            $subscribers[$e['email']] = true;
        }
        
        foreach ($customers as &$customer) {
            $customer['country'] = isset($customer['billing']['countryId']) ? $country[$customer['billing']['countryId']] : '';
            $customer['subscribed'] = isset($subscribers[$customer['email']]);
        }

        return array('data' => $customers, 'total' => $countCustomers);
    }

    /**
     * @param string $email
     * @param array $params
     * @return \Shopware\Models\Customer\Customer
     * @throws \Shopware\Components\Api\Exception\ValidationException
     * @throws \Shopware\Components\Api\Exception\NotFoundException
     * @throws \Shopware\Components\Api\Exception\ParameterMissingException
     * @throws \Shopware\Components\Api\Exception\CustomValidationException
     */
    public function update($email, array $params)
    {
        $this->checkPrivilege('update');

        if (empty($email)) {
            throw new ApiException\ParameterMissingException();
        }

        if ($params['Unsubscribe']) {
            /** @var $article \Shopware\Models\Newsletter\Address */
            $customer = $this->getRepositoryAddress()->findOneBy(array('email' => $email));
            $this->getManager()->remove($customer);
            $this->flush();        
            return true;
        }

        return false;
    }    
}
