<?php

class Shopware_Controllers_Api_NewsletterCustomers extends Shopware_Controllers_Api_Rest
{
    /**
     * @var Shopware\Components\Api\Resource\NewsletterCustomer
     */
    protected $resource = null;

    public function init()
    {
        $this->resource = \Shopware\Components\Api\Manager::getResource('NewsletterCustomer');
    }

    /**
     * Get list of customers
     *
     * GET /api/newsletterCustomers/
     */
    public function indexAction()
    {
        $sort   = $this->Request()->getParam('sort', array());
        $filter = $this->Request()->getParam('filter', array());
        $subscribed = $this->Request()->getParam('subscribed', false);
        $countOnly = $this->Request()->getParam('countonly', false);
        $offset = $this->Request()->getParam('start', false);
        $limit  = $this->Request()->getParam('limit', false);

        $onlySubscribers = $this->Request()->getParam('onlySubscribers', false);

        if ($onlySubscribers) {
            $result = $this->getOnlySubscribers();
        } else {
            $result = $this->resource->getList($filter, $sort, $subscribed, $countOnly, $offset, $limit);
        }

        $this->View()->assign($result);
        $this->View()->assign('success', true);
    }
    
    /**
     * Test connection
     *
     * GET /api/newsletterCustomers/test/
     */
    public function getAction()
    {
        $this->View()->assign('success', true);
    }

    /**
     * Update customer
     *
     * PUT /api/newsletterCustomers/{email}
     */
    public function putAction()
    {
        $email = $this->Request()->getParam('id');
        $params = $this->Request()->getPost();

        $this->resource->update($email, $params);
        
        $this->View()->assign(array('success' => true));
    }
    
    private function getOnlySubscribers() 
    {
        $q = 'SELECT distinct email FROM s_campaigns_mailaddresses WHERE email NOT IN (SELECT email from s_user)';
        $subscribers = Shopware()->Db()->fetchAll($q);
        $customers = array();
        foreach ($subscribers as $email) {
            $customers[] = array(
                'crm_id' => 0,
                'firstname' => '',
                'lastname' => '',
                'gender' => '',
                'mail' => $email['email'],
                'mobile' => '',
                'birthday' => '',
                'company_name' => '',
                'street' => '',
                'zip' => '',
                'city' => '',
                'country' => '',
                'subscribed' => true,
            );
        }

        return array('data' => $customers, 'total' => count($customers));
    }
}
